@@ -1,6 +1,6 @@
 from __future__ import annotations
 import pydash as __
-from typing import Optional, List, _GenericAlias, get_type_hints, ForwardRef
+from typing import Optional, List, ForwardRef
 from datetime import datetime
 from gstorm.helpers.gql import setup_gql
 from pprint import pprint
@@ -10,6 +10,7 @@ from gstorm.QueryBuilder import QueryBuilder
 from gstorm.enums import QueryType
 from gstorm.BaseGraphQLType import BaseGraphQLType
 from gstorm.helpers.date_helpers import get_local_date, iso8601_to_local_date
+from gstorm.helpers.typing_helpers import attrs_with_hints
 
 
 def nint(value):
@@ -33,11 +34,11 @@ class GraphQLType(BaseGraphQLType):
     __sync__: bool = attr.ib(repr=False, default=False)
     __errors__: List[dict] = attr.ib(repr=False, factory=list)
     id: Optional[int] = attr.ib(
-        default=None, converter=nint, metadata={'unique': {}})
+        default=None, converter=nint, metadata={'unique': {}, 'type': int, 'model': None})
     insertedAt: datetime = attr.ib(repr=False, factory=lambda: get_local_date(
-        datetime.now()), converter=iso8601_to_local_date, metadata={'readonly': True})
+        datetime.now()), converter=iso8601_to_local_date, metadata={'readonly': True, 'type': datetime, 'model': None})
     updatedAt: datetime = attr.ib(repr=False, factory=lambda: get_local_date(
-        datetime.now()), converter=iso8601_to_local_date, metadata={'readonly': True})
+        datetime.now()), converter=iso8601_to_local_date, metadata={'readonly': True, 'type': datetime, 'model': None})
 
     def __attrs_post_init__(self):
         """[summary]
@@ -69,11 +70,10 @@ class GraphQLType(BaseGraphQLType):
     @classmethod
     def get_base_fields(cls):
         list_fields = [
-            name
-            for name, hint in get_type_hints(cls).items()
+            name for name, hint in attrs_with_hints(cls).items()
             if hint != List[GraphQLType]  # if not type List
             # GraphQL types are forward-referenced
-            and not type(hint) == ForwardRef
+            and not isinstance(hint, ForwardRef)
             and not name.startswith('_')
         ]
         return list_fields
@@ -82,8 +82,8 @@ class GraphQLType(BaseGraphQLType):
     def get_list_fields(cls):
         list_fields = [
             name
-            for name, hint in get_type_hints(cls).items()
-            if hint == List[GraphQLType]  # if not type List
+            for name, hint in attrs_with_hints(cls).items()
+            if hint == List[GraphQLType]  # if type List[GraphQLType]
         ]
         return list_fields
 
@@ -91,9 +91,9 @@ class GraphQLType(BaseGraphQLType):
     def get_object_fields(cls, typename=None):
         obj_fields = {
             name: hint
-            for name, hint in get_type_hints(cls).items()
+            for name, hint in attrs_with_hints(cls).items()
             if (
-                type(hint) == ForwardRef
+                isinstance(hint, ForwardRef)
                 # and hint.__forward_arg__ == typename if typename else True # filters by object type
             )
         }
@@ -101,7 +101,7 @@ class GraphQLType(BaseGraphQLType):
             obj_fields = {
                 name: hint
                 for name, hint in obj_fields.items()
-                if hint.__forward_arg__ == typename
+                if typename in hint.__forward_arg__
             }
         return list(obj_fields.keys())
 
@@ -115,7 +115,7 @@ class GraphQLType(BaseGraphQLType):
 
     @classmethod
     def get_field_types(cls):
-        return {k: v for k, v in get_type_hints(cls).items() if not k.startswith('_')}
+        return {k: v for k, v in attrs_with_hints(cls).items() if not k.startswith('_')}
 
     @classmethod
     def get_metadata(cls, field_name):
