@@ -28,9 +28,11 @@ def scalar_map(field_typename):
         'String': 'String',
         'Text': 'Text',
         'Json': 'map',
+        'Jsonb': 'map',
         'Date': 'Date',
         'Time': 'Time',
-        'Datetime': 'DateTime'
+        'Datetime': 'DateTime',
+        'ID': 'ID'
     }[field_typename]
 
 
@@ -42,9 +44,11 @@ def get_field_kind(field_typename):
         'String',
         'Text',
         'Json',
+        'Jsonb',
         'Date',
         'Time',
-        'Datetime'
+        'Datetime',
+        'ID'
     ]
     if field_typename in scalar_types:
         return 'SCALAR'
@@ -154,11 +158,16 @@ def gql_schema_parse(schema_file_lines):
                     tokens) < 3 else '@has_one' == tokens[2]
                 field_is_unique = False if len(
                     tokens) < 3 else '@unique' == tokens[2]
+                if len(tokens) < 3 or not '@default' in tokens[2]:
+                    field_default = None
+                else:
+                    field_default = tokens[3][:-1]
                 current_field = {}
                 # current_field['required'] = field_is_required
                 # current_field['is_unique'] = field_is_unique
                 current_field['unique'] = field_is_unique
                 current_field['has_one'] = field_has_one
+                current_field['default'] = field_default
                 current_field['name'] = field_name
                 current_field['type'] = {
                     'name': field_typename if field_kind == 'OBJECT' else scalar_map(field_typename),
@@ -197,9 +206,10 @@ def gql_schema_parse(schema_file_lines):
 def load_schema_from_file(src):
     try:
         clean_schema_lines = inmemory_cleanup(src)
-    except FileNotFoundError as e:
+        return gql_schema_parse(clean_schema_lines)
+    except FileNotFoundError:
         log(LogLevel.ERROR, f'File {src} not found')
-    return gql_schema_parse(clean_schema_lines)
+        return
 
 
 def prettify_query(query):
