@@ -1,3 +1,6 @@
+import sys
+from functools import lru_cache
+from typing import Type, Dict, Any, ForwardRef, _eval_type
 from importlib import import_module
 from enum import Enum
 from gstorm import BaseGraphQLType
@@ -103,3 +106,39 @@ def gql_list_repr(values):
         return '[]'
     else:
         return f'[{type(values[0]).__name__}({len(values)})]'
+
+
+@lru_cache
+def attrs_with_hints(model: Type) -> Dict[str, Any]:
+    """Method to return the attributes of a given class
+    with the corresponding hints.
+
+    Args:
+    ------
+        - model (Type): Model to obtain its attributes with hints
+
+    Return:
+    ------
+        - Dict with the attr as key and the hint as value
+    """
+    mapped_attrs: Dict[str, Any] = {}  # Dictionary for the attributes
+    for base_class in model.__mro__:
+        # Iterate over the annotations of the base class
+        for key, hint in base_class.__dict__.get("__annotations__", {}).items():
+            # Obtain the import from the file where it resides this base class
+            global_variables = sys.modules[base_class.__module__].__dict__
+            if hint in global_variables:
+                mapped_attrs[key] = global_variables[hint]
+            elif hint in global_variables["__builtins__"]:
+                mapped_attrs[key] = global_variables["__builtins__"][hint]
+            else:
+                # For those that are not directly in the global variables, try to evaluate them
+                # as a forward reference. For Python <=3.8, it would not fail the `try` block and
+                # it would work as expected. In Python >=3.8, if it fail with a `NameError`, then
+                # it's an GraphQLType model.
+                try:
+                    mapped_attrs[key] = _eval_type(
+                        ForwardRef(hint), global_variables, locals())
+                except NameError:
+                    mapped_attrs[key] = ForwardRef(hint)
+    return mapped_attrs
